@@ -1096,8 +1096,7 @@ def populate_efitviewer_figure(
         printe('Gridspec keywords for setting up efitviewer profile plots were invalid and were ignored!')
 
     if show_cx:
-        pyplot.figure(num=fig.number)
-        cx_ax = scratch['efitviewer_cx_ax'] = pyplot.subplot(gs[:, 0])
+        cx_ax = scratch['efitviewer_cx_ax'] = fig.add_subplot(gs[:, 0])
     else:
         cx_ax = scratch['efitviewer_cx_ax'] = None
 
