@@ -75,13 +75,56 @@ class OMFITlatex(OMFITtree):
         self.style_types = ['cls', 'sty', 'clo', 'bst']
         self.no_load = ['OMFIT_run_command.sh', 'OMFITlatex_settings.dat']
         self.pdflatex_flags = '-halt-on-error'  # This string is inserted between pdflatex and command line arguments
-
         self.hide_style_files = hide_style_files  # Not in settings because ugly to change after init.
+        self.__mainroot = mainroot
+        self.__export_path = export_path
+        self.__main = main
+        self.__export_after_build = export_after_build
+        self.__hide_style_files = hide_style_files
 
+        # Define sub-folder to isolate LaTeX stuff from other I/O from the module to avoid accidentally picking up
+        # unrelated files
+        self.latex_folder = 'OMFITlatex_{}'.format(id(self))
+        printd('OMFITlatex self.latex_folder = {}'.format(self.latex_folder), topic='latex')
+
+        # Figure out the parent module root
+        self.root = OMFIT if root is None else root
+
+        # Deal with servers an directories
+        self.lookup_dirs_and_servers()
+        if local_build:
+            self.server = 'localhost'
+            self.tunnel = ''
+            self.remotedir = SERVER['localhost']['workDir']
+
+        # Load settings and sub-folders
+        self.prepare_settings()
+        printd('Done with OMFITlatex initialization', topic='latex')
+        return
+
+    def prepare_settings(self):
+
+        main = self.__main
+        mainroot = self.__mainroot
+        export_path = self.__export_path
+        export_after_build = self.__export_after_build
+        hide_style_files = self.__hide_style_files
+
+        # Prepare settings
+        try:
+            self.setdefault('settings', OMFITnamelist('OMFITlatex_settings.dat'))
+        except OSError:
+            # This can happen if the class is being initialized while OMFIT is still loading.
+            # The project load sequence will put settings in for us, so we can skip this part.
+            printd('Unable to prepare OMFITlatex settings at this time.', topic='latex')
+            return
+
+        printd('Preparing OMFITlatex settings...', topic='latex')
+
+        # These sub-folders should also be loaded by the project if that's what's happening
         self['__aux__'] = OMFITtree()
         if hide_style_files:
             self['__sty__'] = OMFITtree()
-        self['settings'] = OMFITnamelist('OMFITlatex_settings.dat')
 
         # Set up name of main file
         if main[-4:] != os.extsep + 'tex':
@@ -116,35 +159,6 @@ class OMFITlatex(OMFITtree):
                 self['settings']['export_path'] = os.path.split(self['settings']['main'])[0]
                 self['settings']['main'] = os.path.split(self['settings']['main'])[1]  # Reduce to filename w/o path
 
-        # Figure out the parent module root
-        self.root = OMFIT if root is None else root
-
-        # Define sub-folder to isolate LaTeX stuff from other I/O from the module to avoid accidentally picking up
-        # unrelated files
-        self.latex_folder = 'OMFITlatex_{}'.format(id(self))
-        printd('OMFITlatex self.latex_folder = {}'.format(self.latex_folder), topic='latex')
-
-        # Link to module settings and define workdir
-        try:
-            module_settings = self.root['SETTINGS']
-            _ = module_settings['SETUP']['workDir']
-            _ = module_settings['REMOTE_SETUP']
-        except (KeyError, TypeError):
-            self.workdir = OMFIT['MainSettings']['SETUP']['workDir'] + os.sep + self.latex_folder
-            self.remotedir = SERVER['default']['workDir'] + os.sep + self.latex_folder
-            self.tunnel = SERVER['default']['tunnel']
-            self.server = SERVER['default']['server']
-        else:
-            self.workdir = module_settings['SETUP']['workDir'] + os.sep + self.latex_folder
-            self.remotedir = module_settings['REMOTE_SETUP']['workDir'] + os.sep + self.latex_folder
-            self.tunnel = module_settings['REMOTE_SETUP']['tunnel']
-            self.server = module_settings['REMOTE_SETUP']['server']
-
-        if local_build:
-            self.server = 'localhost'
-            self.tunnel = ''
-            self.remotedir = SERVER['localhost']['workDir']
-
         # Set up root filename of main file
         if mainroot is None:
             self['settings']['mainroot'] = self['settings']['main'].split(os.extsep + 'tex')[0]
@@ -157,7 +171,74 @@ class OMFITlatex(OMFITtree):
         self['settings']['export_after_build'] = export_after_build
         self['settings']['default_build_sequence'] = 'full'
         self['settings']['default_clean_before_build'] = False
-        return
+        printd('Done preparing OMFITlatex settings.', topic='latex')
+
+    def lookup_dirs_and_servers(self, overwrite=False):
+        """
+        Looks up workdir, remotedir, tunnel, and server
+
+        Tries to link to module or top-level settings to get information.
+
+        :param overwrite: bool
+            Overwrite existing attributes. Otherwise, attributes with valid definitions will not be updated.
+        """
+
+        printd('Looking up directory and server information...', topic='latex')
+        # Link to module settings and define workdir, etc.
+        try:
+            module_settings = self.root['SETTINGS']
+            _ = module_settings['SETUP']['workDir']
+            _ = module_settings['REMOTE_SETUP']
+        except (KeyError, TypeError):
+            printd('  Drawing dir & server info from MainSettings...', topic='latex')
+            ref_workdir = evalExpr(OMFIT['MainSettings']['SETUP']['workDir'])
+            ref_remotedir = evalExpr(SERVER['default']['workDir'])
+            tunnel = evalExpr(SERVER['default']['tunnel'])
+            server = evalExpr(SERVER['default']['server'])
+        else:
+            printd('  Drawing dir & server info from parent module SETTINGS...', topic='latex')
+            ref_workdir = evalExpr(module_settings['SETUP']['workDir'])
+            ref_remotedir = evalExpr(module_settings['REMOTE_SETUP']['workDir'])
+            tunnel = evalExpr(module_settings['REMOTE_SETUP']['tunnel'])
+            server = evalExpr(module_settings['REMOTE_SETUP']['server'])
+
+        printd(
+            f'  Found ref_workdir = {repr(ref_workdir)}, ref_remotedir = {repr(ref_remotedir)}, '
+            f'server = {repr(server)}, tunnel = {repr(tunnel)}',
+            topic='latex',
+        )
+        # If workdir and remotedir are valid directories, extend them by adding the latex_folder
+        if ref_workdir is None or isinstance(ref_workdir, NamelistName):
+            # Not sure why it comes back as NamelistName sometimes, but it does.
+            workdir = None
+        else:
+            workdir = ref_workdir + os.sep + self.latex_folder
+        if ref_remotedir is None or isinstance(ref_workdir, NamelistName):
+            remotedir = None
+        else:
+            remotedir = ref_remotedir + os.sep + self.latex_folder
+
+        # If workdir and remotedir are missing, signal that we shouldn't trust tunnel and server
+        if workdir is None and remotedir is None:
+            printd(
+                "Failed to find useful info about directories & servers. This can happen during project loading. ",
+                topic='latex',
+            )
+            tunnel = server = None
+
+        # Load data
+        if (getattr(self, 'workdir', None) is None) or overwrite:
+            self.workdir = workdir
+            printd(f'  Set self.workdir = {self.workdir}', topic='latex')
+        if (getattr(self, 'remotedir', None) is None) or overwrite:
+            self.remotedir = remotedir
+            printd(f'  Set self.remotedir = {self.remotedir}', topic='latex')
+        if (getattr(self, 'tunnel', None) is None) or overwrite:
+            self.tunnel = tunnel
+            printd(f'  Set self.tunnel = {self.tunnel}', topic='latex')
+        if (getattr(self, 'server', None) is None) or overwrite:
+            self.server = server
+            printd(f'  Set self.server = {self.server}', topic='latex')
 
     def __call__(self, **kw):
         return self.run(**kw)
@@ -173,6 +254,8 @@ class OMFITlatex(OMFITtree):
             Gather .tex files as well (only recommended during init)
         """
         if main_dir is None:
+            if self.workdir is None:
+                self.lookup_dirs_and_servers()
             main_dir = self.workdir
         destination = self
         depth = 0
@@ -247,6 +330,8 @@ class OMFITlatex(OMFITtree):
             The path to which files should be exported.
         """
         # from OMFITx import executable
+        if self.workdir is None:
+            self.lookup_dirs_and_servers()
 
         if export_path is None:
             export_path = self['settings']['export_path']
@@ -385,6 +470,8 @@ class OMFITlatex(OMFITtree):
 
         printd('Building latex project ({:})...'.format(self['settings']['main']), topic='latex')
 
+        if None in [self.workdir, self.remotedir, self.tunnel, self.server]:
+            self.lookup_dirs_and_servers()
         if sequence is None:
             sequence = self['settings']['default_build_sequence']
         if clean_before_build is None:
