@@ -19,6 +19,7 @@ import numpy as np
 
 __all__ = ['OMFITmars', 'OMFITnColumns', 'OMFITmarsProfile']
 
+
 class OMFITmars(SortedDict, OMFITobject):
     """
     Class used to interface with MARS results directory
@@ -1023,20 +1024,22 @@ class OMFITmars(SortedDict, OMFITobject):
 
         if fig is None:
             fig = pyplot.figure()
-        ax1 = fig.add_subplot(2, 2, 1)
+        else:
+            pyplot.figure(num=fig.number)
+        ax1 = pyplot.subplot(2, 2, 1)
         ax1.plot(self[self.sim]['s'], np.real(self[self.sim]['RM']))
         ax1.set_ylabel('Re(R_m)')
 
-        ax2 = fig.add_subplot(2, 2, 2)
+        ax2 = pyplot.subplot(2, 2, 2)
         ax2.plot(self[self.sim]['s'], np.imag(self[self.sim]['RM']))
         ax2.set_ylabel('Im(R_m)')
 
-        ax3 = fig.add_subplot(2, 2, 3)
+        ax3 = pyplot.subplot(2, 2, 3)
         ax3.plot(self[self.sim]['s'], np.real(self[self.sim]['ZM']))
         ax3.set_ylabel('Re(Z_m)')
         ax3.set_xlabel('s')
 
-        ax4 = fig.add_subplot(2, 2, 4)
+        ax4 = pyplot.subplot(2, 2, 4)
         ax4.plot(self[self.sim]['s'], np.imag(self[self.sim]['ZM']))
         ax4.set_ylabel('Im(Z_m)')
         ax4.set_xlabel('s')
@@ -1051,7 +1054,10 @@ class OMFITmars(SortedDict, OMFITobject):
 
         if fig is None:
             fig = pyplot.figure()
-        ax = fig.add_subplot(1, 1, 1)
+        else:
+            pyplot.figure(num=fig.number)
+
+        ax = pyplot.subplot(1, 1, 1)
         Ns = self[self.sim]['Ns1'].values.astype(int) + self[self.sim]['Ns2'].values.astype(int)
         Rplot = self[self.sim]['R'][0:Ns, :].values
         Zplot = self[self.sim]['Z'][0:Ns, :].values
@@ -1071,7 +1077,10 @@ class OMFITmars(SortedDict, OMFITobject):
 
         if fig is None:
             fig = pyplot.figure()
-        ax = fig.add_subplot(1, 1, 1)
+        else:
+            pyplot.figure(num=fig.number)
+
+        ax = pyplot.subplot(1, 1, 1)
         Ns = self[self.sim]['Ns1'].values.astype(int) + self[self.sim]['Ns2'].values.astype(int)
         Ns1 = self[self.sim]['Ns1'].values.astype(int)
         Rtot = self[self.sim]['R'][0:Ns, :].values
@@ -1104,24 +1113,27 @@ class OMFITmars(SortedDict, OMFITobject):
 
         if fig is None:
             fig = pyplot.figure()
+        else:
+            pyplot.figure(num=fig.number)
+
         ax = None
         label = 'JPLASMA'
         MM = self[label]['Mm'].values
         labelstring = [str(m) for m in MM]
         for k, c in enumerate(['JM1', 'JM2', 'JM3']):
-            ax = ax1 = fig.add_subplot(3, 2, 2 * k + 1, sharex=ax)
+            ax = ax1 = pyplot.subplot(3, 2, 2 * k + 1, sharex=ax)
             ax1.plot(self[label]['s'], np.real(self[label][c]))
             for i, line in enumerate(ax1.lines):
                 line.set_label(labelstring[i])
             lines1 = ax1.get_lines()
-            labelLines(lines1[np.abs(np.min(MM))+1:np.abs(np.min(MM))+Mmax+1], xvals=(0.,1.), align=False)
+            labelLines(lines1[np.abs(np.min(MM)) + 1 : np.abs(np.min(MM)) + Mmax + 1], xvals=(0.0, 1.0), align=False)
             ax1.set_title('Re($J^%d_m$)' % (k + 1), y=0.8)
-            ax2 = fig.add_subplot(3, 2, 2 * (k + 1), sharex=ax)
+            ax2 = pyplot.subplot(3, 2, 2 * (k + 1), sharex=ax)
             ax2.plot(self[label]['s'], np.imag(self[label][c]))
             for i, line in enumerate(ax2.lines):
                 line.set_label(labelstring[i])
             lines2 = ax2.get_lines()
-            labelLines(lines2[np.abs(np.min(MM))+1:np.abs(np.min(MM))+Mmax+1], xvals=(0.,1.), align=False)
+            labelLines(lines2[np.abs(np.min(MM)) + 1 : np.abs(np.min(MM)) + Mmax + 1], xvals=(0.0, 1.0), align=False)
             ax2.set_title('Im($J^%d_m$)' % (k + 1), y=0.8)
         ax1.set_xlabel('s')
         ax2.set_xlabel('s')
@@ -1136,7 +1148,10 @@ class OMFITmars(SortedDict, OMFITobject):
 
         if fig is None:
             fig = pyplot.figure()
-        ax = fig.add_subplot(1, 1, 1)
+        else:
+            pyplot.figure(num=fig.number)
+
+        ax = pyplot.subplot(1, 1, 1)
         label = 'FREQUENCIES'
         ax.plot(self[label]['s'], self[label]['we'], 'k-', label=r'$\omega_E$')
         ax.plot(self[label]['s'], self[label]['wsni'] + self[label]['wsti'], 'g-', label=r'$\omega_*^{thi}$')
@@ -1159,24 +1174,27 @@ class OMFITmars(SortedDict, OMFITobject):
 
         if fig is None:
             fig = pyplot.figure()
+        else:
+            pyplot.figure(num=fig.number)
+
         ax = None
         label = 'BPLASMA'
         MM = self[label]['Mm'].values
         labelstring = [str(m) for m in MM]
         for k, c in enumerate(['BM1', 'BM2', 'BM3']):
-            ax = ax1 = fig.add_subplot(3, 2, 2 * k + 1, sharex=ax)
+            ax = ax1 = pyplot.subplot(3, 2, 2 * k + 1, sharex=ax)
             ax1.plot(self[label]['s'], np.real(self[label][c]))
             for i, line in enumerate(ax1.lines):
                 line.set_label(labelstring[i])
             lines1 = ax1.get_lines()
-            labelLines(lines1[np.abs(np.min(MM))+1:np.abs(np.min(MM))+Mmax+1], xvals=(0.,1.), align=False)
+            labelLines(lines1[np.abs(np.min(MM)) + 1 : np.abs(np.min(MM)) + Mmax + 1], xvals=(0.0, 1.0), align=False)
             ax1.set_title('Re($B^%d_m$)' % (k + 1), y=0.8)
-            ax2 = fig.add_subplot(3, 2, 2 * (k + 1), sharex=ax)
+            ax2 = pyplot.subplot(3, 2, 2 * (k + 1), sharex=ax)
             ax2.plot(self[label]['s'], np.imag(self[label][c]))
             for i, line in enumerate(ax2.lines):
                 line.set_label(labelstring[i])
             lines2 = ax2.get_lines()
-            labelLines(lines2[np.abs(np.min(MM))+1:np.abs(np.min(MM))+Mmax+1], xvals=(0.,1.), align=False)
+            labelLines(lines2[np.abs(np.min(MM)) + 1 : np.abs(np.min(MM)) + Mmax + 1], xvals=(0.0, 1.0), align=False)
             ax2.set_title('Im($B^%d_m$)' % (k + 1), y=0.8)
         ax1.set_xlabel('s')
         ax2.set_xlabel('s')
@@ -1193,24 +1211,27 @@ class OMFITmars(SortedDict, OMFITobject):
 
         if fig is None:
             fig = pyplot.figure()
+        else:
+            pyplot.figure(num=fig.number)
+
         ax = None
         label = 'XPLASMA'
         MM = self[label]['Mm'].values
         labelstring = [str(m) for m in MM]
         for k, c in enumerate(['XM1', 'XM2', 'XM3']):
-            ax1 = fig.add_subplot(3, 2, 2 * k + 1, sharex=ax)
+            ax1 = pyplot.subplot(3, 2, 2 * k + 1, sharex=ax)
             ax1.plot(self[label]['sp'], np.real(self[label][c]))
             for i, line in enumerate(ax1.lines):
                 line.set_label(labelstring[i])
             lines1 = ax1.get_lines()
-            labelLines(lines1[np.abs(np.min(MM))+1:np.abs(np.min(MM))+Mmax+1], xvals=(0.,1.), align=False)
+            labelLines(lines1[np.abs(np.min(MM)) + 1 : np.abs(np.min(MM)) + Mmax + 1], xvals=(0.0, 1.0), align=False)
             ax1.set_title('Re($X^%d_m$)' % (k + 1), y=0.8)
-            ax2 = fig.add_subplot(3, 2, 2 * (k + 1), sharex=ax)
+            ax2 = pyplot.subplot(3, 2, 2 * (k + 1), sharex=ax)
             ax2.plot(self[label]['sp'], np.imag(self[label][c]))
             for i, line in enumerate(ax2.lines):
                 line.set_label(labelstring[i])
             lines2 = ax2.get_lines()
-            labelLines(lines2[np.abs(np.min(MM))+1:np.abs(np.min(MM))+Mmax+1], xvals=(0.,1.), align=False)
+            labelLines(lines2[np.abs(np.min(MM)) + 1 : np.abs(np.min(MM)) + Mmax + 1], xvals=(0.0, 1.0), align=False)
             ax2.set_title('Im($X^%d_m$)' % (k + 1), y=0.8)
         ax1.set_xlabel('sp')
         ax2.set_xlabel('sp')
@@ -1225,12 +1246,17 @@ class OMFITmars(SortedDict, OMFITobject):
 
         if fig is None:
             fig = pyplot.figure()
+        else:
+            pyplot.figure(num=fig.number)
+
+        ax = pyplot.subplot(1, 1, 1)
+
         label = 'XPLASMA'
         if 'R' not in self[self.sim]:
             self.get_RZ()
         if 'Xn' not in self[label]:
             self.get_X123()
-        ax = fig.add_subplot(1, 1, 1)
+
         Irat = self[self.sim]['Iratsurf']
         # Plasma displacement defined within plasma boundary
         Ns1 = self[self.sim]['Ns1'].values
@@ -1257,12 +1283,17 @@ class OMFITmars(SortedDict, OMFITobject):
 
         if fig is None:
             fig = pyplot.figure()
+        else:
+            pyplot.figure(num=fig.number)
+
+        ax = pyplot.subplot(1, 1, 1)
+
         label = 'BPLASMA'
         if 'R' not in self[self.sim]:
             self.get_RZ()
         if 'Bn' not in self[label]:
             self.get_B123()
-        ax = fig.add_subplot(1, 1, 1)
+
         Irat = self[self.sim]['Iratsurf']
         # Pick last s-grid point for Bn plotting
         if II:
@@ -1293,6 +1324,9 @@ class OMFITmars(SortedDict, OMFITobject):
 
         if fig is None:
             fig = pyplot.figure()
+        else:
+            pyplot.figure(num=fig.number)
+
         if II:
             Ns = II
         else:
@@ -1312,20 +1346,20 @@ class OMFITmars(SortedDict, OMFITobject):
         label = 'BPLASMA'
         BR = self[label]['Br'].values
         BZ = self[label]['Bz'].values
-        ax1 = fig.add_subplot(2, 2, 1)
+        ax1 = pyplot.subplot(2, 2, 1)
         ax1.plot(Tw, np.real(BR[Ns, JJ]), linewidth=2)
         ax1.set_ylabel('Re($\delta B_R$) [Gauss]')
 
-        ax2 = fig.add_subplot(2, 2, 2)
+        ax2 = pyplot.subplot(2, 2, 2)
         ax2.plot(Tw, np.imag(BR[Ns, JJ]), linewidth=2)
         ax2.set_ylabel('Im($\delta B_R$) [Gauss]')
 
-        ax3 = fig.add_subplot(2, 2, 3)
+        ax3 = pyplot.subplot(2, 2, 3)
         ax3.plot(Tw, np.real(BZ[Ns, JJ]), linewidth=2)
         ax3.set_ylabel('Re($\delta B_Z$) [Gauss]')
         ax3.set_xlabel('GEOM angle')
 
-        ax4 = fig.add_subplot(2, 2, 4)
+        ax4 = pyplot.subplot(2, 2, 4)
         ax4.plot(Tw, np.imag(BZ[Ns, JJ]), linewidth=2)
         ax4.set_ylabel('Im($\delta B_Z$) [Gauss]')
         ax4.set_xlabel('GEOM angle')
@@ -1340,7 +1374,10 @@ class OMFITmars(SortedDict, OMFITobject):
 
         if fig is None:
             fig = pyplot.figure()
-        ax = fig.add_subplot(1, 1, 1)
+        else:
+            pyplot.figure(num=fig.number)
+
+        ax = pyplot.subplot(1, 1, 1)
         Ns = self[self.sim]['Ns1'].values
         chi = self[self.sim]['chi'].values
         label = 'BPLASMA'
@@ -1359,9 +1396,14 @@ class OMFITmars(SortedDict, OMFITobject):
 
         if fig is None:
             fig = pyplot.figure()
+        else:
+            pyplot.figure(num=fig.number)
+
+        ax = pyplot.subplot(1, 1, 1)
+
         Ns = self[self.sim]['Ns1'].values
         label = 'BPLASMA'
-        ax = fig.add_subplot(1, 1, 1)
+
         Br = self[label]['Br'].isel(s=range(Ns)).values
         Bz = self[label]['Bz'].isel(s=range(Ns)).values
         Bphi = self[label]['Bphi'].isel(s=range(Ns)).values
@@ -1385,11 +1427,16 @@ class OMFITmars(SortedDict, OMFITobject):
 
         if fig is None:
             fig = pyplot.figure()
+        else:
+            pyplot.figure(num=fig.number)
+
+        ax = pyplot.subplot(1, 1, 1)
+
         label = 'DWK_ENERGY_DENSITY'
         csm = self[label]['s']
         dWki_re = self[label]['0_0_REdwk']
         dWki_im = self[label]['0_0_IMdwk']
-        ax = fig.add_subplot(1, 1, 1)
+
         pyplot.plot(csm, dWki_re, 'bo-', label=r'Re($\delta W_k$) total')
         pyplot.plot(csm, dWki_im, 'rs--', label=r'Im($\delta W_k$) total')
         ax.set_xlabel('s')
@@ -1406,6 +1453,11 @@ class OMFITmars(SortedDict, OMFITobject):
 
         if fig is None:
             fig = pyplot.figure()
+        else:
+            pyplot.figure(num=fig.number)
+
+        ax = pyplot.subplot(1, 1, 1)
+
         NSPECIES = self['DWK_COMPONENTS']['NSPECIES'].values
         labels = ['NTD', 'NTB', 'NP']
         ions = [self['DWK_COMPONENTS']['K_I_NTD'], self['DWK_COMPONENTS']['K_I_NTB'], self['DWK_COMPONENTS']['K_I_NP']]
@@ -1421,7 +1473,6 @@ class OMFITmars(SortedDict, OMFITobject):
                 ]
         x = np.arange(len(labels))
         width = 0.35
-        ax = fig.add_subplot(1, 1, 1)
         ax.bar(x - width / 2, ions, width, label='Ions')
         ax.bar(x + width / 2, electrons, width, label='Electrons')
         if NSPECIES > 2:
@@ -1434,6 +1485,7 @@ class OMFITmars(SortedDict, OMFITobject):
         ax.legend(loc=0)
         fig.tight_layout()
 
+
 class OMFITnColumns(SortedDict, OMFITascii):
     r"""
     OMFIT class used to interface with n-columns input files
@@ -1485,9 +1537,11 @@ class OMFITnColumns(SortedDict, OMFITascii):
             pyplot.ylabel(self._OMFITkeyName)
             pyplot.tight_layout()
 
+
 class OMFITmarsProfile(OMFITnColumns):
     pass
 
+
 ############################################
 if '__main__' == __name__:
     test_classes_main_header()
