@@ -312,11 +312,11 @@ class OMFITtglf_flux_spectrum(OMFITdataset, OMFITascii):
             for s in range(ns):
                 for f in range(nf):
                     if s == 0 and f == 0:
-                        ax0 = ax = axr = fig.add_subplot(ns, nf, s * nf + f + 1)
+                        ax0 = ax = axr = fig.add_subplot(ns, nf, s * nf + f + 1)  # OKadd
                     elif f == 0:
-                        ax = axr = fig.add_subplot(ns, nf, s * nf + f + 1, sharex=ax0)
+                        ax = axr = fig.add_subplot(ns, nf, s * nf + f + 1, sharex=ax0)  # OKadd
                     else:
-                        ax = fig.add_subplot(ns, nf, s * nf + f + 1, sharex=ax0, sharey=axr)
+                        ax = fig.add_subplot(ns, nf, s * nf + f + 1, sharex=ax0, sharey=axr)  # OKadd
                     if f == 0:
                         ax.set_ylabel('Species: %s' % (self.spec_labels[s]))
                     if s == 0:
